<?php

namespace Guru\Product\Providers;

use Illuminate\Support\ServiceProvider;

class ProductServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'product');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'product');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('product', function ($app) {
            return $this->app->make('Guru\Product\Product');
        });

// Bind Product to repository
        $this->app->bind(
            \Guru\Product\Interfaces\ProductRepositoryInterface::class,
            \Guru\Product\Repositories\Eloquent\ProductRepository::class
        );        // Bind Category to repository
        $this->app->bind(
            \Guru\Product\Interfaces\CategoryRepositoryInterface::class,
            \Guru\Product\Repositories\Eloquent\CategoryRepository::class
        );        // Bind Price to repository
        $this->app->bind(
            \Guru\Product\Interfaces\PriceRepositoryInterface::class,
            \Guru\Product\Repositories\Eloquent\PriceRepository::class
        );

        $this->app->register(\Guru\Product\Providers\AuthServiceProvider::class);
        $this->app->register(\Guru\Product\Providers\EventServiceProvider::class);
        $this->app->register(\Guru\Product\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['product'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/product.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/product')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/product')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
